@@ -67,18 +67,34 @@ soothing = [
 	
 	]
 
+none = []
+
 boogie = [
 	BoogieWoogieRhythm({'channel': 1, 'midi_instr': randrange(25, 31)}),
+	BoogieWoogieRhythm({'channel': 2, 'midi_instr': randrange(1, 10)}),
 	RockDrum({}),
 	SoloInstrument({'channel':11, 'midi_instr': randrange(25, 90)}),
 	BassInstrument({'channel':5, 'midi_instr':36, 'let_ring': True}),
 	]
 
+rocknroll= [
+	BoogieWoogieRhythm({'channel': 1, 'midi_instr': 29, 'start':2, 'step': 2}),
+	BoogieWoogieRhythm({'channel': 3, 'midi_instr': 30, 'start': 4, 'step': 2}),
+	BoogieWoogieRhythm({'channel': 2, 'midi_instr': 4, 'start': 0}),
+	RockDrum({}),
+	SoloInstrument({'channel':11, 'midi_instr': 30}),
+	BassInstrument({'channel':5, 'midi_instr':36, 'let_ring': True}),
+	Strings({'channel': 6, 'start': 4, 'midi_instr': 49, 'step': 4, 'let_ring': True}), 
+	]
+
 metal = [
 	BlastBeat({'max_velocity': 80}),
 	PowerChords({'channel': 7, 'midi_instr': 30}),
-	SoloInstrument({'channel':6, 'midi_instr': 32}),
+	ChromaticSoloist({'channel':6, 'midi_instr': 29, 'max_velocity':80, 'start': 0, 'step':4}),
+	ChromaticSoloist({'channel':8, 'midi_instr': 28, 'max_velocity':80, 'start': 4, 'step':4}),
 	BassInstrument({'channel':5, 'midi_instr':36}),
+	Strings({'channel': 1, 'start': 4, 'midi_instr': 49, 'step': 4, 'let_ring': True}), 
+	Strings({'channel': 1, 'start': 8, 'midi_instr': 30, 'step': 4, 'let_ring': True}), 
 	]
 
 jazz = [
