@@ -1,5 +1,6 @@
 #!/usr/bin/env python
 from Sequencer import Sequencer
+import Blocks
 from Blocks import Block
 from os import sys
 from optparse import OptionParser
@@ -30,11 +31,27 @@ def get_available_instruments():
 		type(Instrument) and issubclass(getattr(Bands,x), Instrument)]
 
 
+def get_available_blocks():
+	return [x for x in Blocks.__dict__ if type(getattr(Blocks, x)) == \
+		type(Block) and issubclass(getattr(Blocks,x), Block)]
+
+def check_options(test, test_func, test_str, module, dest):
+
+	if test != None:
+		if test in test_func():
+			dest = getattr(module, test)
+			return dest
+		else:
+			print "Unknown %s:" % test_str, test
+			return False
+	return False
+
 if __name__ == '__main__':
 
 	parser = OptionParser()
 	parser.add_option("-b", "--bpm", dest="bpm", type="int",
 		help="Set the bpm to start with.")
+	parser.add_option("--block", dest="block", help="Set the block to start with.")
 	parser.add_option("-d", "--duration", dest="duration", type="int",
 		help="Set the number of times the progression should be repeated.")
 	parser.add_option("-e", "--ensemble", dest="ensemble", 
@@ -45,7 +62,7 @@ if __name__ == '__main__':
 		default=400, help='Height of the visualization screen')
 	parser.add_option("-i", "--instrument", help="Play using only one instrument", dest="instrument")
 	parser.add_option("-l", "--list", dest="list", 
-		help="List [bands, progressions]. Don't play.")
+		help="List [blocks, ensembles, progressions, instruments]. Don't play.")
 	parser.add_option("-k", "--key", dest="key",
 		help="Set the key to start in.")
 	parser.add_option("-p", "--progression", dest="progression",
@@ -67,7 +84,12 @@ if __name__ == '__main__':
 
 
 	visual = None
-	block = Block()
+	b = check_options(options.block, get_available_blocks, 
+			"block", Blocks, visual)
+	if b != False:
+		block = b()
+	else:
+		block = Block()
 	block.swing = options.swing
 	block.resolution = options.resolution
 	w = options.width
@@ -84,8 +106,8 @@ if __name__ == '__main__':
 		visual = PygameMixedVisualizations(w,h)
 
 	if options.list != None:
-		if options.list == "bands" or \
-			options.list[0] == 'b':
+		if options.list == "ensembles" or \
+			options.list[0] == 'e':
 			i = 1
 			for x in get_available_bands():
 				print "%d. %s" % (i, x)
@@ -102,34 +124,39 @@ if __name__ == '__main__':
 			for x in get_available_instruments():
 				print "%d. %s" % (i, x)
 				i += 1
+		elif options.list == "blocks" or\
+			options.list[0] == 'b':
+			i = 1
+			for x in get_available_blocks():
+				print "%d. %s" % (i, x)
+				i += 1
 		else:
 			print "Unknown list", options.list
 		sys.exit(0)
 
-	if options.ensemble != None:
-		if options.ensemble in get_available_bands():
-			block.instruments = getattr(Bands, 
-					options.ensemble)
-		else:
-			if options.verbose:
-				print "Unknown ensemble:", options.ensemble
+	b = check_options(options.ensemble, get_available_bands, 
+			"ensemble", Bands, block.instruments)
+	if b != False:
+		block.instruments = b
+
+	b = check_options(options.progression, get_available_progressions,
+			"progression", Progressions, block.progressions)
+	if b != False:
+		block.progressions = b
+
 
-	if options.progression != None:
-		if options.progression in get_available_progressions():
-			block.progressions = getattr(Progressions, 
-					options.progression)
-		else:
-			if options.verbose:
-				print "Unknown progression:", options.progression
 
 	if options.instrument != None:
-		if options.instrument in get_available_instruments():
-			i = getattr(Musicians, options.instrument)
-			i = i({'channel': 1, 'start': 0})
-			block.instruments = [i]
-		else:
-			if options.verbose:
-				print "Unknown instrument:", options.instrument
+		for inst in options.instrument.split(","):
+			c =0 
+			if inst in get_available_instruments():
+				i = getattr(Musicians, inst)
+				i = i({'channel': c, 'start': 0})
+				c += 1
+				block.instruments += [i]
+			else:
+				if options.verbose:
+					print "Unknown instrument:", inst
 
 	if options.key != None:
 		if notes.is_valid_note(options.key):
